<?php
/*
	Plugin Name: SC Catalog
	Description: Introduce products or services (or anything else) with in a galery with picture, title and catch-phrase. Get more information by clicking on it.
	Version: 1.3.0
	Author: Scil
	Author URI: http://scil.coop
	Licence: GPL2 or any later

	Copyright 2011-2012 SARL SCOP Scil (email : contact@scil.coop)
		
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// check for WP context
if ( !defined('ABSPATH') ){ die(); }

define( "SC_CATALOG_DB_VERSION", 2 );
define( "SC_CATALOG_DB_TABLE", "sc_catalog" );
define( "SC_CATALOG_OPTION_DB_VER", "sc_catalog_db_version" );

/** @private */
function _sc_catalog_table() {
	global $wpdb;
	return $wpdb->prefix . SC_CATALOG_DB_TABLE;
}

function sc_catalog_install() {
	global $wpdb;
	$table = _sc_catalog_table();
	$current_version = get_option( SC_CATALOG_OPTION_DB_VER, NULL );
	$db_ok = ( 1 === $wpdb->query( 'SHOW TABLES like "' . $table . '";' ) );
	// Check if table is there and versionned
	if ( NULL === $current_version || ! $db_ok)  {
		// Delete potential junk
		$wpdb->query( "DROP TABLE $table;" );
		delete_option( SC_CATALOG_OPTION_DB_VER );
		// Install database
		$sql = "CREATE TABLE $table (
		          id INT(11) NOT NULL AUTO_INCREMENT,
		          title TEXT NOT NULL,
		          catch TEXT NOT NULL,
		          image VARCHAR(255) NOT NULL,
		          text TEXT NOT NULL,
		          disp_order INT(11) NOT NULL,
		          category TEXT,
		          UNIQUE KEY id (id) );";
		$wpdb->query( $sql );
		add_option( SC_CATALOG_OPTION_DB_VER, SC_CATALOG_DB_VERSION, '', 'no');
	} else {
		// It is there but outdated, upgrade database
		switch ( $current_version ) {
		case 1:
			$sql = "ALTER TABLE $table ADD category TEXT";
			$wpdb->query( $sql );
			break;
		}
		update_option( SC_CATALOG_OPTION_DB_VER, SC_CATALOG_DB_VERSION );
	}
}
register_activation_hook( __FILE__, 'sc_catalog_install' );

function sc_catalog_upgrade() {
	// Check db version and update it if required
	if ( get_option( SC_CATALOG_OPTION_DB_VER, NULL ) !== SC_CATALOG_DB_VERSION) {
		sc_catalog_install();
	}
}
add_action('plugins_loaded', 'sc_catalog_upgrade');

function sc_catalog_uninstall() {
	global $wpdb;
	delete_option( SC_CATALOG_OPTION_DB_VER );
	$wpdb->query( 'DROP TABLE ' . _sc_catalog_table() );
}
register_uninstall_hook( __FILE__, 'sc_catalog_uninstall' );

function sc_catalog_init() {
	$lang_dir = basename( dirname( __FILE__ ) ) . '/languages';
	load_plugin_textdomain( 'sc_cat', false, $lang_dir );
}
add_action( 'init', 'sc_catalog_init' );

// Add custom style
function sc_catalog_styles() {
	wp_enqueue_style( 'thickbox' );
	wp_enqueue_style( 'sc-catalog', plugins_url( '/sc-catalog.css', __FILE__ ) );
}
add_action( 'wp_print_styles', 'sc_catalog_styles' );

function sc_catalog_scripts() {
	wp_enqueue_script( 'thickbox' );
}
add_action( 'wp_print_scripts', 'sc_catalog_scripts' );

// Import data manipulation functions
require_once( dirname( __FILE__ ) . "/sc-catalog-data.php" );
// Register shortcode
require_once( dirname( __FILE__ ) . "/sc-catalog-shortcode.php" );
// Register admin options
require_once( dirname( __FILE__ ) . "/sc-catalog-admin.php" );
